
## Release Notes

**v0.6.2 - May 11, 2022**

* **FIXED** doc fixes
* **UNFEATURE** Removing Python 2 support

**v0.6.1 - July 10, 2020**

* **ENHANCEMENT** Unit tests now added for command-line tools
* **FIXED** Command-line tools now correctly parse arguments
* **FIXED** Regex matching of warp image URLs updated to match filename changes made by STScI PanSTARRS image server

**v0.6.0 - May 7, 2020**

* Now compatible with Python 3.\*
